@@ -13,7 +13,7 @@ class LibraryItem;
 class eDiode;
 class eResistor;
 
-class MAINMODULE_EXPORT SCR : public Component, public eElement
+class SCR : public Component, public eElement
 {
     public:
         SCR( QString type, QString id );
@@ -36,7 +36,7 @@ class MAINMODULE_EXPORT SCR : public Component, public eElement
         double holdCurr() { return m_holdCurr; }
         void setHoldCurr( double v ) { m_holdCurr = v; m_changed = true; }
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 
     private:
         double m_gateRes;
