@@ -15,21 +15,23 @@
 
 #include "doubleprop.h"
 
-Component* VoltReg::construct( QObject* parent, QString type, QString id )
-{ return new VoltReg( parent, type, id ); }
+#define tr(str) simulideTr("VoltReg",str)
+
+Component* VoltReg::construct( QString type, QString id )
+{ return new VoltReg( type, id ); }
 
 LibraryItem* VoltReg::libraryItem()
 {
     return new LibraryItem(
-        QCoreApplication::translate("VoltReg", "Volt. Regulator"),
+        tr("Volt. Regulator"),
         "Other Active",
         "voltreg.png",
         "VoltReg",
         VoltReg::construct );
 }
 
-VoltReg::VoltReg( QObject* parent, QString type, QString id )
-       : Component( parent, type, id )
+VoltReg::VoltReg( QString type, QString id )
+       : Component( type, id )
        , eResistor( id )
 {
     m_area = QRect( -11, -8, 22, 19 );
@@ -41,13 +43,11 @@ VoltReg::VoltReg( QObject* parent, QString type, QString id )
     m_pin.resize( 3 );
     m_ePin.resize( 3 );
 
-    m_ePin[0] = m_pin[0] = new Pin( 180, QPoint( -16, 0 ), id+"-input", 0, this );
-    m_pin[0]->setLength(5);
+    m_ePin[0] = m_pin[0] = new Pin( 180, QPoint( -16, 0 ), id+"-input", 0, this, 5 );
     m_pin[0]->setLabelText( "I" );
     m_pin[0]->setLabelColor( QColor( 0, 0, 0 ) );
 
-    m_ePin[1] = m_pin[1] = new Pin( 0, QPoint( 16, 0 ), id+"-output", 1, this );
-    m_pin[1]->setLength(5);
+    m_ePin[1] = m_pin[1] = new Pin( 0, QPoint( 16, 0 ), id+"-output", 1, this, 5 );
     m_pin[1]->setLabelText( "O" );
     m_pin[1]->setLabelColor( QColor( 0, 0, 0 ) );
 
@@ -59,8 +59,9 @@ VoltReg::VoltReg( QObject* parent, QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<VoltReg>("Voltage", tr("Output Voltage"),"V", this, &VoltReg::outVolt, &VoltReg::setOutVolt )
-    },0} );
+new DoubProp<VoltReg>("Voltage", tr("Output Voltage"),"V"
+                     , this, &VoltReg::outVolt, &VoltReg::setOutVolt )
+    },0 } );
 
     setShowProp("Voltage");
     setPropStr( "Voltage", "1.2" );
@@ -119,4 +120,6 @@ void VoltReg::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
 {
     Component::paint( p, option, widget );
     p->drawRect( m_area );
+
+    Component::paintSelected( p );
 }
