@@ -55,10 +55,15 @@ Demux::Demux( QString type, QString id )
     setAddrBits( 3 );
 
     addPropGroup( { tr("Main"), {
-new IntProp<Demux>("Address_Bits", tr("Address Size"),"_bits", this, &Demux::addrBits, &Demux::setAddrBits,0,"uint" )
-    },groupNoCopy} );
-    addPropGroup( { tr("Electric"), IoComponent::inputProps()+IoComponent::outputProps()+IoComponent::outputType(),0 } );
-    addPropGroup( { tr("Edges")   , IoComponent::edgeProps(),0 } );
+new IntProp<Demux>("Address_Bits", tr("Address Size"),"_bits"
+                  , this , &Demux::addrBits, &Demux::setAddrBits, propNoCopy,"uint" )
+    }, groupNoCopy } );
+
+    addPropGroup( { tr("Electric"), IoComponent::inputProps()
+                                  + IoComponent::outputProps()
+                                  + IoComponent::outputType(),0 } );
+
+    addPropGroup( { tr("Timing")  , IoComponent::edgeProps(),0 } );
 }
 Demux::~Demux(){}
 
@@ -163,4 +168,6 @@ void Demux::paint( QPainter *p, const QStyleOptionGraphicsItem *option, QWidget
         QPointF( w,-h-6 )};
 
     p->drawPolygon(points, 4);
+
+    Component::paintSelected( p );
 }
