@@ -45,6 +45,7 @@ KY040::KY040( QString type, QString id )
      : Component( type, id )
      , eElement( id )
 {
+    m_graphical = true;
     m_changed = false;
     m_area = QRect( -WIDTH/2, -HEIGHT/2 + GAP, WIDTH, HEIGHT );
 
@@ -92,7 +93,8 @@ KY040::KY040( QString type, QString id )
     QObject::connect( m_button, &QToolButton::released, [=](){ onbuttonchanged(); } );
 
     addPropGroup( { tr("Main"), {
-new IntProp<KY040>( "Steps", tr("Steps per Rotation"),tr("_Steps"), this, &KY040::steps, &KY040::setSteps,0,"uint" )
+new IntProp<KY040>("Steps", tr("Steps per Rotation"),""
+                  , this, &KY040::steps, &KY040::setSteps,0,"uint" )
     }, groupNoCopy} );
 }
 KY040::~KY040(){}
@@ -190,4 +192,6 @@ void KY040::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
     
     p->setBrush(QColor( 50, 50, 70 ));
     p->drawRoundedRect( m_area, 2, 2 );
+
+    Component::paintSelected( p );
 }
