@@ -25,7 +25,7 @@ LibraryItem* Image::libraryItem()
     return new LibraryItem(
         tr("Image"),
         "Graphical",
-        "image.png",
+        "img.png",
         "Image",
         Image::construct);
 }
@@ -42,7 +42,8 @@ Image::Image( QString type, QString id )
     m_movie = NULL;
 
     addPropGroup( {"Hidden", {
-new StrProp<Image>("Image_File", tr("Image File"),"", this, &Image::background, &Image::setBackground )
+new StrProp<Image>("Image_File", tr("Image File"),""
+                  , this, &Image::background, &Image::setBackground )
     }, groupNoCopy | groupHidden} );
 }
 Image::~Image()
@@ -135,4 +136,5 @@ void Image::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
         p->setBrush( Qt::transparent );
         p->drawRect( m_area );
     }
+    Component::paintSelected( p );
 }
