@@ -70,20 +70,28 @@ SevenSegment::SevenSegment( QString type, QString id )
     setNumDisplays( 1 );
 
     addPropGroup( { tr("Main"), {
-new StrProp <SevenSegment>("Color", tr("Color"),"", this, &SevenSegment::colorStr, &SevenSegment::setColorStr,0,"enum" ),
-new IntProp <SevenSegment>("NumDisplays"  , tr("Size"),"_7seg", this
-                          , &SevenSegment::numDisplays, &SevenSegment::setNumDisplays, propNoCopy ),
+        new StrProp <SevenSegment>("Color", tr("Color"), ""
+                                  , this, &SevenSegment::colorStr, &SevenSegment::setColorStr,0,"enum" ),
+
+        new IntProp <SevenSegment>("NumDisplays"  , tr("Size"),"_7seg"
+                                  , this, &SevenSegment::numDisplays, &SevenSegment::setNumDisplays, propNoCopy ),
+
+        new BoolProp<SevenSegment>("Vertical_Pins", tr("Vertical Pins"), ""
+                                  , this, &SevenSegment::verticalPins, &SevenSegment::setVerticalPins, propNoCopy )
+            }, 0} );
 
-new BoolProp<SevenSegment>("Vertical_Pins", tr("Vertical Pins"),"" , this
-                          , &SevenSegment::verticalPins, &SevenSegment::setVerticalPins, propNoCopy )
-    }, 0} );
     addPropGroup( { tr("Electric"), {
-new BoolProp<SevenSegment>("CommonCathode", tr("Common Cathode") ,"",  this
-                          , &SevenSegment::isComCathode, &SevenSegment::setComCathode, propNoCopy ),
+        new BoolProp<SevenSegment>("CommonCathode", tr("Common Cathode"), ""
+                                  , this, &SevenSegment::isComCathode, &SevenSegment::setComCathode, propNoCopy ),
 
-new DoubProp<SevenSegment>("Threshold" , tr("Forward Voltage"),"V", this, &SevenSegment::threshold,  &SevenSegment::setThreshold ),
-new DoubProp<SevenSegment>("MaxCurrent", tr("Max Current")    ,"A", this, &SevenSegment::maxCurrent, &SevenSegment::setMaxCurrent ),
-new DoubProp<SevenSegment>("Resistance", tr("Resistance")     ,"Ω", this, &SevenSegment::resistance, &SevenSegment::setResistance ),
+        new DoubProp<SevenSegment>("Threshold" , tr("Forward Voltage"),"V"
+                                  , this, &SevenSegment::threshold, &SevenSegment::setThreshold ),
+
+        new DoubProp<SevenSegment>("MaxCurrent", tr("Max Current"),"mA"
+                                  , this, &SevenSegment::maxCurrent, &SevenSegment::setMaxCurrent ),
+
+        new DoubProp<SevenSegment>("Resistance", tr("Resistance"),"Ω"
+                                  , this, &SevenSegment::resistance, &SevenSegment::setResistance ),
     },0} );
 }
 SevenSegment::~SevenSegment() { }
@@ -280,8 +288,10 @@ void SevenSegment::setHidden( bool hid, bool hidArea, bool hidLabel )
     else      m_area = QRect(-18,-24-4, 32*m_numDisplays+4, 48+8 );
 }
 
-void SevenSegment::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void SevenSegment::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
 {
-    Component::paint( p, option, widget );
+    Component::paint( p, o, w );
     p->drawRect( m_area );
+
+    Component::paintSelected( p );
 }
