@@ -10,18 +10,18 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT VarResistor : public VarResBase
+class VarResistor : public VarResBase
 {
     public:
-        VarResistor( QObject* parent, QString type, QString id );
+        VarResistor( QString type, QString id );
         ~VarResistor();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void updateStep() override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget *widget ) override;
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 };
 
 #endif
