@@ -7,12 +7,12 @@
 #define SUBPACKAGE_H
 
 #include "chip.h"
-#include "linkable.h"
+#include "linker.h"
 
 class LibraryItem;
 class QAction;
 
-class MAINMODULE_EXPORT SubPackage : public Chip, public Linkable
+class SubPackage : public Chip, public Linker
 {
         friend class Circuit;
 
@@ -29,7 +29,7 @@ class MAINMODULE_EXPORT SubPackage : public Chip, public Linkable
         int height() { return m_height; }
         void setHeight( int height );
         
-        QString  package();
+        QString package();
         void setPackage( QString package );
 
         void setEventPin( Pin* pin ) { m_eventPin = pin; }
@@ -37,6 +37,7 @@ class MAINMODULE_EXPORT SubPackage : public Chip, public Linkable
         void savePackage( QString fileName );
         virtual void setSubcTypeStr( QString s ) override;
         virtual void setLogicSymbol( bool ls ) override;
+
         virtual void remove() override;
 
         virtual void compSelected( Component* comp ) override;  // Use link mechanism to select main components
@@ -51,9 +52,10 @@ class MAINMODULE_EXPORT SubPackage : public Chip, public Linkable
         void setPinSpace( double space );
         void boardModeSlot();
         void setBoardMode( bool mode );
-        void mainComp() { Linkable::startLinking(); }
+        void mainComp() { Linker::startLinking(); }
         void unusePin( bool unuse );
-        void pointPin( bool point );
+        void setPointPin( bool point );
+        void setBusPin( bool bus );
         void editPin();
         void deleteEventPin();
     
@@ -106,10 +108,10 @@ class EditDialog : public QDialog
     public:
         EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent = 0 );
 
-    private slots:
-        void invertPin( bool invert );
-
     private:
+        void setPointPin( bool p );
+        void setBusPin( bool b );
+
         SubPackage* m_package;
 
         QLabel*    m_nameLabel;
@@ -127,6 +129,7 @@ class EditDialog : public QDialog
         QCheckBox* m_invertCheckBox;
         QCheckBox* m_unuseCheckBox;
         QCheckBox* m_pointCheckBox;
+        QCheckBox* m_busCheckBox;
 };
 
 #endif
