@@ -14,7 +14,7 @@
 
 #include "mcucpu.h"
 
-class MAINMODULE_EXPORT AvrCore : public McuCpu
+class AvrCore : public McuCpu
 {
     public:
         AvrCore( eMcu* mcu );
@@ -41,6 +41,4 @@ class MAINMODULE_EXPORT AvrCore : public McuCpu
         void flags_zns16( uint16_t res );
         int  is_instr_32b( uint32_t pc );
 };
-
-
 #endif
